+++
title = "Page Bundle (File-based Flow)"
description = "Post organized as a _Page Bundle_  exported using _file-based flow_."
tags = ["file-based", "page-bundles"]
draft = false
+++

This post is exported to a [Page/Leaf Bundle structure](https://scripter.co/hugo-leaf-and-branch-bundles/#leaf-bundle).
